@@ -18,12 +18,13 @@
 #include <zypp/ZConfig.h>
 #include <zypp/Date.h>
 #include <zypp/PoolItem.h>
+#include <zypp/Patch.h>
 
 #include "Zypper.h"
 #include "PackageArgs.h"
 #include "utils/misc.h" // for ResKindSet; might make sense to move this elsewhere
+#include "global-settings.h"
 
-class Out;
 
 ///////////////////////////////////////////////////////////////////
 /// \class CliMatchPatch
@@ -41,7 +42,7 @@ struct CliMatchPatch
     {
       if ( val && ( !_dateBefore || val < _dateBefore ) )
       {
-	_dateBefore = val;
+        _dateBefore = val;
       }
     }
     _categories = std::move( categories_r );
@@ -75,11 +76,11 @@ struct CliMatchPatch
     if ( patch_r )	// non-patches pass
     {
       if ( _dateBefore && patch_r->timestamp() > _dateBefore )
-	return Missmatch::Date;
+        return Missmatch::Date;
       if ( ! ( _categories.empty() || patch_r->isCategory( _categories ) ) )
-	return Missmatch::Category;
+        return Missmatch::Category;
       if ( ! ( _severities.empty() || patch_r->isSeverity( _severities ) ) )
-	return Missmatch::Severity;
+        return Missmatch::Severity;
     }
     return Missmatch::None;
   }
@@ -128,7 +129,7 @@ public:
       , best_effort( false )
       , skip_interactive( false )
       , skip_optional_patches( false )
-      , allow_vendor_change( ZConfig::instance().solver_allowVendorChange() )
+      , allow_vendor_change( tri2bool( SolverSettings::instance()._allowVendorChange, ZConfig::instance().solver_allowVendorChange() ) )
     {}
 
     void setForceByName( bool value = true );
@@ -289,9 +290,9 @@ public:
     };
 
     Feedback( const Id id,
-	      const PackageSpec & reqpkg,
-	      const PoolItem & selected = PoolItem(),
-	      const PoolItem & installed = PoolItem() )
+              const PackageSpec & reqpkg,
+              const PoolItem & selected = PoolItem(),
+              const PoolItem & installed = PoolItem() )
     : _id( id )
     , _reqpkg( reqpkg )
     , _objsel( selected )
@@ -456,9 +457,9 @@ private:
   void addConflict( const PackageSpec & pkg );
 
   void addFeedback( const Feedback::Id id,
-		    const PackageSpec & reqpkg,
-		    const PoolItem & selected = PoolItem(),
-		    const PoolItem & installed = PoolItem() )
+                    const PackageSpec & reqpkg,
+                    const PoolItem & selected = PoolItem(),
+                    const PoolItem & installed = PoolItem() )
   { _feedback.push_back( Feedback( id, reqpkg, selected, installed ) ); }
 
   void addFeedback( const Feedback::Id id_r, const PackageSpec & reqpkg_r, std::string userdata_r )
@@ -466,7 +467,7 @@ private:
 
 private:
   /** Various options to be applied to each requested package */
-  Options _opts;
+  const Options _opts;
 
   /** Requester command being executed.
    * \note This may be different from command given on command line.
