@@ -17,6 +17,7 @@
 #include <zypp/Url.h>
 
 #include "Zypper.h"
+#include "utils/prompt.h"
 
 // auto-repeat counter limit
 #define REPEAT_LIMIT 3
@@ -37,10 +38,10 @@ namespace ZmartRecipients
         if (u==url)
         {
           if (++counter>=REPEAT_LIMIT)
-	  {
-	    counter = 0;	// reset!: next request might use the same URL again.
+          {
+            counter = 0;	// reset!: next request might use the same URL again.
             return true;
-	  }
+          }
         }
         else
         {
@@ -98,15 +99,14 @@ namespace ZmartRecipients
 
     virtual void start( const Url & uri, Pathname localfile )
     {
-      _last_reported = time(NULL);
       _last_drate_avg = -1;
 
       Out & out = Zypper::instance().out();
 
       if (out.verbosity() < Out::HIGH &&
            (
-             // don't show download info unless show_media_progress_hack is used
-             !Zypper::instance().runtimeData().show_media_progress_hack ||
+             // don't show download info unless scopedVerboseDownloadProgress is demanded
+             not Zypper::instance().runtimeData().scopedVerboseDownloadProgress.isDemanded() ||
              // don't report download of the media file (bnc #330614)
              Pathname(uri.getPathName()).basename() == "media"
            )
@@ -123,13 +123,6 @@ namespace ZmartRecipients
 
     virtual bool progress(int value, const Url & uri, double drate_avg, double drate_now)
     {
-      // don't report more often than 1 second
-      time_t now = time(NULL);
-      if (now > _last_reported)
-        _last_reported = now;
-      else
-        return !Zypper::instance().exitRequested();
-
       Zypper & zypper( Zypper::instance() );
 
       if (zypper.exitRequested())
@@ -153,8 +146,13 @@ namespace ZmartRecipients
     virtual DownloadProgressReport::Action
     problem( const Url & uri, DownloadProgressReport::Error error, const std::string & description )
     {
-      DBG << "media problem" << std::endl;
-      if (_be_quiet)
+      if ( error == DownloadProgressReport::NO_ERROR ) {
+        // NO_ERROR: just a report but let the caller proceed as appropriate...
+        Zypper::instance().out().info() << "- " << ( ColorContext::LOWLIGHT << description );
+        return DownloadProgressReport::IGNORE;
+      }
+
+      if ( not _be_quiet )
         Zypper::instance().out().dwnldProgressEnd(uri, _last_drate_avg, true);
       Zypper::instance().out().error(zcb_error2str(error, description));
 
@@ -177,7 +175,6 @@ namespace ZmartRecipients
 
   private:
     bool _be_quiet;
-    time_t _last_reported;
     double _last_drate_avg;
   };
 
