@@ -125,7 +125,7 @@ int ZypperBaseCommand::parseArguments( Zypper &, const int argc, char * const *a
 
   if ( _fillRawOptions ) {
     //skip first argument here as well
-    for ( int i = 1; i < argc; i++ ) {
+    for ( int i = 1; i < argc; ++i ) {
       _rawOptions.push_back( argv[ i ] );
     }
   }
@@ -193,6 +193,7 @@ int ZypperBaseCommand::defaultSystemSetup( Zypper &zypper, SetupSystemFlags flag
   if ( zypper.exitCode() != ZYPPER_EXIT_OK )
     return zypper.exitCode();
 
+#if 0 // since libzypp 17.23.0 the Resolver auto establishes the PPP status.
   if ( flags_r.testFlag ( Resolve ) ) {
     // have REPOS and TARGET
     // compute status of PPP
@@ -200,6 +201,7 @@ int ZypperBaseCommand::defaultSystemSetup( Zypper &zypper, SetupSystemFlags flag
     base::LogControl::TmpLineWriter shutUp;	// reduce logging; some day libzypp/libsolv may offer a shotcut to establish
     resolve( zypper );
   }
+#endif
 
   return zypper.exitCode();
 }
@@ -234,6 +236,9 @@ void ZypperBaseCommand::setPositionalArguments(const std::vector<std::string> &p
   _positionalArguments = positionalArguments;
 }
 
+int ZypperBaseCommand::earlyPositionalArgsCheck( Zypper &zypper, const std::vector<std::string> &positionalArgs )
+{ return ZYPPER_EXIT_OK; }
+
 int ZypperBaseCommand::run( Zypper &zypper )
 {
   MIL << "run: " << command().front() << endl;
@@ -248,14 +253,16 @@ int ZypperBaseCommand::run( Zypper &zypper )
       }
     }
 
-    int code = systemSetup( zypper );
-    if ( code != ZYPPER_EXIT_OK )
+    if ( int code = earlyPositionalArgsCheck( zypper, _positionalArguments ); code != ZYPPER_EXIT_OK )
+      return code;
+
+    if ( int code = systemSetup( zypper ); code != ZYPPER_EXIT_OK )
       return code;
 
     return execute( zypper, _positionalArguments );
   }
 
-  // ZypperBaseCommand's should actually handle all exceptions themselfes, however
+  // ZypperBaseCommand's should actually handle all exceptions themselves, however
   // for compatibility reasons we better catch those here again
   //
   // TODO Someday redesign the Exceptions flow.
