@@ -37,17 +37,6 @@ struct MiscQueryInitMixin : public T
     if ( code != ZYPPER_EXIT_OK )
       return code;
 
-    // needed to compute status of PPP
-    // Currently CleandepsOnRemove adds information about user selected packages,
-    // which enhances the computation of unneeded packages. Might be superfluous in the future.
-    AutoDispose<bool> restoreCleandepsOnRemove( God->resolver()->cleandepsOnRemove(),
-                                                bind( &Resolver::setCleandepsOnRemove, God->resolver(), _1 ) );
-    God->resolver()->setCleandepsOnRemove( true );
-
-    code = T::defaultSystemSetup( zypper, Resolve );
-    if ( code != ZYPPER_EXIT_OK )
-      return code;
-
     return T::execute ( zypper, positionalArgs_r );
 
   }
