@@ -118,7 +118,7 @@ bool confirm_licenses( Zypper & zypper )
       {
         bool differ = false;
         for_( inst, selectable->installedBegin(), selectable->installedEnd() )
-	  if ( inst->resolvable()->licenseToConfirm() != piLicenseToConfirm )
+          if ( inst->resolvable()->licenseToConfirm() != piLicenseToConfirm )
           { differ = true; break; }
 
         if ( !differ )
@@ -132,12 +132,12 @@ bool confirm_licenses( Zypper & zypper )
       bool auto_agree = auto_agree_all || ( auto_agree_product && pi.isKind<Product>() );
       if ( auto_agree )
       {
-	zypper.out().info(
-	  // translators: the first %s is name of the resolvable,
-	  // the second is its kind (e.g. 'zypper package')
-	  str::Format(_("Automatically agreeing with %s %s license."))
-	  % get_display_name( pi )
-	  % kind_to_string_localized(pi.kind(),1) );
+        zypper.out().info(
+          // translators: the first %s is name of the resolvable,
+          // the second is its kind (e.g. 'zypper package')
+          str::Format(_("Automatically agreeing with %s %s license."))
+          % get_display_name( pi )
+          % kind_to_string_localized(pi.kind(),1) );
 
         MIL << "Automatically agreeing with " << pi.name() << " " <<  pi.kind() << " license." << endl;
         continue;
@@ -158,17 +158,17 @@ bool confirm_licenses( Zypper & zypper )
     {
       if ( pi.needToAcceptLicense() )
       {
-	if ( !toAccept )
-	  toAccept = true;
+        if ( !toAccept )
+          toAccept = true;
 
-	std::string kindstr;
-	if ( pi.kind() != ResKind::package )
-	  kindstr = " (" + kind_to_string_localized( pi.kind(), 1 ) + ")";
-	// introduction
-	// translators: the first %s is the name of the package, the second
-	// is " (package-type)" if other than "package" (patch/product/pattern)
-	s << str::form(_("In order to install '%s'%s, you must agree to terms of the following license agreement:"),
-		       get_display_name( pi ).c_str(), kindstr.c_str()) << endl;
+        std::string kindstr;
+        if ( pi.kind() != ResKind::package )
+          kindstr = " (" + kind_to_string_localized( pi.kind(), 1 ) + ")";
+        // introduction
+        // translators: the first %s is the name of the package, the second
+        // is " (package-type)" if other than "package" (patch/product/pattern)
+        s << str::form(_("In order to install '%s'%s, you must agree to terms of the following license agreement:"),
+                       get_display_name( pi ).c_str(), kindstr.c_str()) << endl;
       }
     }
     if ( toAccept )
@@ -188,32 +188,32 @@ bool confirm_licenses( Zypper & zypper )
       //! \todo add 'v' option to view the license again, add prompt help
       if ( !read_bool_answer( PROMPT_YN_LICENSE_AGREE, question, false ) )
       {
-	if ( zypper.config().non_interactive )
-	{
-	  zypper.out().info(_("Aborting installation due to the need for license confirmation."), Out::QUIET );
-	  zypper.out().info(
-	    // translators: %s is '--auto-agree-with-licenses'
-	    str::Format(_("Please restart the operation in interactive mode and confirm your agreement with required licenses, or use the %s option."))
-	    % "--auto-agree-with-licenses", Out::QUIET );
+        if ( zypper.config().non_interactive )
+        {
+          zypper.out().info(_("Aborting installation due to the need for license confirmation."), Out::QUIET );
+          zypper.out().info(
+            // translators: %s is '--auto-agree-with-licenses'
+            str::Format(_("Please restart the operation in interactive mode and confirm your agreement with required licenses, or use the %s option."))
+            % "--auto-agree-with-licenses", Out::QUIET );
 
-	  MIL << "License(s) NOT confirmed (non-interactive without auto confirmation)" << endl;
-	}
-	else
-	{
-	  for ( const PoolItem & pi : el.second )
-	  {
-	    if ( pi.needToAcceptLicense() )
-	    {
-	      zypper.out().info(
-		// translators: e.g. "... with flash package license."
-		str::Format(_("Aborting installation due to user disagreement with %s %s license."))
-		% get_display_name( pi )
-		% kind_to_string_localized( pi.kind(), 1 ), Out::QUIET );
-	    }
-	  }
-	  MIL << "License(s) NOT confirmed (interactive)" << endl;
-	}
-	return false;
+          MIL << "License(s) NOT confirmed (non-interactive without auto confirmation)" << endl;
+        }
+        else
+        {
+          for ( const PoolItem & pi : el.second )
+          {
+            if ( pi.needToAcceptLicense() )
+            {
+              zypper.out().info(
+                // translators: e.g. "... with flash package license."
+                str::Format(_("Aborting installation due to user disagreement with %s %s license."))
+                % get_display_name( pi )
+                % kind_to_string_localized( pi.kind(), 1 ), Out::QUIET );
+            }
+          }
+          MIL << "License(s) NOT confirmed (interactive)" << endl;
+        }
+        return false;
       }
     }
   }
@@ -265,7 +265,7 @@ void report_licenses( Zypper & zypper )
       if ( inst_with_repo && !inst_with_repo.licenseToConfirm().empty() )
       {
         cout << _("EULA") << ":" << endl;
-	printRichText( cout, inst_with_repo.licenseToConfirm() );
+        printRichText( cout, inst_with_repo.licenseToConfirm() );
         cout << endl;
 
         ++count_installed_eula;
@@ -383,7 +383,7 @@ void build_deps_install( Zypper & zypper, const PackageSpec &spec, bool buildDep
 
   for ( SrcPackage::constPtr srcpkg : srcpkgs )
   {
-    DBG << "Injecting build requieres for " << srcpkg << endl;
+    DBG << "Injecting build requires for " << srcpkg << endl;
 
     // install build depenendcies only
     if ( buildDepsOnly_r )
@@ -403,7 +403,7 @@ void build_deps_install( Zypper & zypper, const PackageSpec &spec, bool buildDep
 
   if ( srcpkgs.empty() && !zypper.config().ignore_unknown )
   {
-    zypper.setExitCode( ZYPPER_EXIT_INF_CAP_NOT_FOUND );
+    zypper.setExitInfoCode( ZYPPER_EXIT_INF_CAP_NOT_FOUND );
   }
 }
 
