@@ -23,6 +23,7 @@
 #include <zypp/PoolItem.h>
 #include <zypp/Product.h>
 #include <zypp/Pattern.h>
+#include <zypp/AutoDispose.h>
 
 #include "main.h"
 #include "Zypper.h"
@@ -43,7 +44,7 @@ bool runningOnEnterprise()
     {
       static const CpeId enterprise( "cpe:/o:suse:sle%02" );
       if ( compare( platform->cpeId(), enterprise, SetRelation::subset ) )
-	ret = true;
+        ret = true;
     }
   return ret;
 }
@@ -126,10 +127,10 @@ std::string i18nPatchStatus( const PoolItem & pi_r )
   {
     case ResStatus::BROKEN:
       if ( pi_r.isUnwanted() )
-	// Translator: Patch status: needed, optional, unwanted, applied, not needed
-	return HIGHLIGHTString( tUnwanted ).str();
+        // Translator: Patch status: needed, optional, unwanted, applied, not needed
+        return HIGHLIGHTString( tUnwanted ).str();
       if ( Zypper::instance().config().exclude_optional_patches && pi_r->asKind<Patch>()->categoryEnum() == Patch::CAT_OPTIONAL )
-	return LOWLIGHTString( tOptional ).str();
+        return LOWLIGHTString( tOptional ).str();
       return tNeeded;
       break;
     case ResStatus::SATISFIED:		return POSITIVEString( tApplied ).str();	break;
@@ -160,9 +161,9 @@ const char * textPatchStatus( const PoolItem & pi_r )
   {
     case ResStatus::BROKEN:
       if ( pi_r.isUnwanted() )
-	return tUnwanted;
+        return tUnwanted;
       if ( Zypper::instance().config().exclude_optional_patches && pi_r->asKind<Patch>()->categoryEnum() == Patch::CAT_OPTIONAL )
-	return tOptional;
+        return tOptional;
       return tNeeded;
       break;
     case ResStatus::SATISFIED:		return tApplied;	break;
@@ -249,9 +250,9 @@ struct PatchHistoryData::D
   {
     if ( auto n { _data.find( solv_r.ident().id() ) }; n != _data.end() ) {
       if ( auto v { n->second.find( solv_r.edition().id() ) }; v != n->second.end() ) {
-	if ( auto a { v->second.find( solv_r.arch().id() ) }; a != v->second.end() ) {
-	  return a->second;
-	}
+        if ( auto a { v->second.find( solv_r.arch().id() ) }; a != v->second.end() ) {
+          return a->second;
+        }
       }
     }
     return noData;
@@ -276,12 +277,12 @@ PatchHistoryData::PatchHistoryData( bool doparse_r )
   {
     const Pathname & historyFile { Pathname::assertprefix( Zypper::instance().config().root_dir, ZConfig::instance().historyLogFile() ) };
     parser::HistoryLogReader parser( historyFile, parser::HistoryLogReader::IGNORE_INVALID_ITEMS,
-				     [=]( HistoryLogData::Ptr ptr_r )->bool {
-				       if ( ! this->_d )
-					 this->_d.reset( new D );
-				       this->_d->remember( dynamic_pointer_cast<HistoryLogPatchStateChange>(ptr_r) );
-				       return true;
-				     } );
+                                     [=]( HistoryLogData::Ptr ptr_r )->bool {
+                                       if ( ! this->_d )
+                                         this->_d.reset( new D );
+                                       this->_d->remember( dynamic_pointer_cast<HistoryLogPatchStateChange>(ptr_r) );
+                                       return true;
+                                     } );
     parser.addActionFilter( HistoryActionID::PATCH_STATE_CHANGE );
     parser.readAll();
   }
@@ -302,10 +303,10 @@ namespace
     if ( PatchHistoryData::value_type res { historyData_r[pi_r] }; res != PatchHistoryData::noData )
     {
       if ( res.second == pi_r.status().validate() )
-	ret = res.first.printISO( Date::TimeFormat::none, Date::TimeZoneFormat::none );
+        ret = res.first.printISO( Date::TimeFormat::none, Date::TimeZoneFormat::none );
       else
-	// patch status was changed by a non zypp transaction (not mentioned in the history)
-	DBG << "PatchHistoryData " << res.second << " but " << pi_r << endl;
+        // patch status was changed by a non zypp transaction (not mentioned in the history)
+        DBG << "PatchHistoryData " << res.second << " but " << pi_r << endl;
     }
     return ret;
   }
@@ -321,7 +322,7 @@ FillPatchesTable::FillPatchesTable( Table & table_r, const PatchHistoryData & hi
 {
   table_r << ( TableHeader()
   << N_("Repository")
-  << N_("Name")
+  << table::Column( N_("Name"), table::CStyle::SortCi )
   << N_("Category")
   << N_("Severity")
   << N_("Interactive")
@@ -363,7 +364,7 @@ FillPatchesTableForIssue::FillPatchesTableForIssue( Table & table_r, const Patch
   //<< _("Repository")
   << N_("Issue")
   << N_("No.")
-  << N_("Patch")	// Name
+  << table::Column( N_("Patch"), table::CStyle::SortCi )	// Name
   << N_("Category")
   << N_("Severity")
   << N_("Interactive")
@@ -480,11 +481,11 @@ namespace
     {
       try
       {
-	ret = parser::ProductFileReader::scanFile( baseproduct.path() );
+        ret = parser::ProductFileReader::scanFile( baseproduct.path() );
       }
       catch ( const Exception & excpt )
       {
-	ZYPP_CAUGHT( excpt );
+        ZYPP_CAUGHT( excpt );
       }
     }
     return ret;
@@ -493,8 +494,12 @@ namespace
 } // namespace
 ///////////////////////////////////////////////////////////////////
 
-Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::string & default_platform )
+Url make_obs_url( const std::string & obsuri )
 {
+  Zypper & zypper { Zypper::instance() };
+  const Url base_url { zypper.config().obs_baseUrl };
+  const std::string default_platform { zypper.config().obs_platform };
+
   // obs-server ==> < base_url, default_platform >
   static std::map<std::string, std::pair<Url,std::string>> wellKnownServers({
     { "build.opensuse.org",	{ Url("https://download.opensuse.org/repositories/"),	std::string() } }
@@ -518,11 +523,11 @@ Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::s
       static str::regex obs_uri2_rx("^(" OBS_PROJECT_NAME_RX ")(/(.*)?)?$");
       if ( str::regex_match( platform, what, obs_uri2_rx ) )
       {
-	project = what[1];
-	platform = ( what[3].empty() ? it->second.second : what[3] );
+        project = what[1];
+        platform = ( what[3].empty() ? it->second.second : what[3] );
       }
       else
-	it = wellKnownServers.end();	// we stay with the 1st match, thus will use the global defaults
+        it = wellKnownServers.end();	// we stay with the 1st match, thus will use the global defaults
     }
 
     // Now bulid the url; ':' in project is replaced by ':/'
@@ -533,43 +538,50 @@ Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::s
 
     if ( platform.empty() )
     {
-      Zypper & zypper( Zypper::instance() );
-
       if ( default_platform.empty() )
       {
-	// Try to guess platform from baseproduct....
-	const parser::ProductFileData & pdata( baseproductdata( zypper.config().root_dir ) );
-	if ( pdata.empty() )
-	{
-	  // Guess failed:
-			     // translators: don't translate '<platform>'
-	  zypper.out().error(_("Unable to guess a value for <platform>."),
-			     _("Please use obs://<project>/<platform>") );
-	  zypper.out().info(str::form(_("Example: %s"), "obs://server:http/openSUSE_11.3"));
-	  return Url();	// FAIL!
-	}
+        // Try to guess platform from baseproduct....
+        const parser::ProductFileData & pdata( baseproductdata( zypper.config().root_dir ) );
+        if ( pdata.empty() )
+        {
+          // Guess failed:
+                             // translators: don't translate '<platform>'
+          zypper.out().error(_("Unable to guess a value for <platform>."),
+                             _("Please use obs://<project>/<platform>") );
+          zypper.out().info(str::form(_("Example: %s"), "obs://zypp:Head/openSUSE_Factory"));
+          return Url();	// FAIL!
+        }
 
-	platform = pdata.name().asString();
-	if ( platform == "openSUSE"  )
-	{
+        platform = pdata.name().asString();
+        if ( platform == "openSUSE"  )
+        {
+          if ( pdata.productline() == "Leap" )
+            platform += "_Leap_$releasever";
+          else if ( str::containsCI( pdata.summary(), "Tumbleweed" ) )
+            platform += "_Tumbleweed";
+          else
+            platform += "_$releasever";
+        }
+        else if ( platform == "MicroOS" && pdata.vendor() == "openSUSE" )
+        {
+          // bsc#1153687 Hotfix
+          platform = "openSUSE_Tumbleweed";
+        }
+        else if ( platform == "Leap" && pdata.vendor() == "openSUSE" )
+        {
+          // bsc#1187425 Hotfix
+          platform = "openSUSE_Leap_$releasever";
+        }
+        else
+          platform += "_$releasever";
 
-	  if ( pdata.productline() == "Leap" )
-	    platform += "_Leap_$releasever";
-	  else if ( str::containsCI( pdata.summary(), "Tumbleweed" ) )
-	    platform += "_Tumbleweed";
-	  else
-	    platform += "_$releasever";
-	}
-	else
-	  platform += "_$releasever";
-
-	zypper.out().info( "Guessed: platform = " + platform );
-	path /= platform;
+        zypper.out().info( "Guessed: platform = " + platform );
+        path /= platform;
       }
       else
       {
-	zypper.out().info( "zypper.conf: obs.platform = " + default_platform );
-	path /= default_platform;
+        zypper.out().info( "zypper.conf: obs.platform = " + default_platform );
+        path /= default_platform;
       }
     }
     else
@@ -581,8 +593,8 @@ Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::s
   }
   else
   {
-    Zypper::instance().out().error(_("Invalid OBS URI."), _("Correct form is obs://<project>/[platform]"));
-    Zypper::instance().out().info(str::form(_("Example: %s"), "obs://server:http/openSUSE_11.3"));
+    zypper.out().error(_("Invalid OBS URI."), _("Correct form is obs://<project>/[platform]"));
+    zypper.out().info(str::form(_("Example: %s"), "obs://zypp:Head/openSUSE_Factory"));
   }
 
   return Url();
@@ -616,7 +628,8 @@ Pathname cache_rpm( const std::string & rpm_uri_str, const Pathname & cache_dir
   try
   {
     media::MediaManager mm;
-    media::MediaAccessId mid = mm.open(rpmurl);
+    AutoDispose<media::MediaAccessId> mid { mm.open(rpmurl) };
+    mid.setDispose( [&mm]( media::MediaAccessId mid ){ mm.release(mid); mm.close(mid); } );
     mm.attach(mid);
 
     mm.provideFile(mid, rpmpath.basename());
@@ -625,9 +638,6 @@ Pathname cache_rpm( const std::string & rpm_uri_str, const Pathname & cache_dir
     bool error =
       filesystem::hardlinkCopy(localrpmpath, cache_dir / localrpmpath.basename());
 
-    mm.release(mid);
-    mm.close(mid);
-
     if ( error )
     {
       Zypper::instance().out().error(
@@ -691,7 +701,7 @@ std::string asXML(const Product & p, bool is_installed , const std::vector<std::
     {
       const std::string & text( p.description() );
       if ( ! text.empty() )
-	*xmlout::Node( *parent, "description" ) << xml::escape( text );
+        *xmlout::Node( *parent, "description" ) << xml::escape( text );
     }
 
     if ( is_installed && fwdTags.size() )
@@ -706,11 +716,11 @@ std::string asXML(const Product & p, bool is_installed , const std::vector<std::
       const Pathname & proddir( Pathname::assertprefix( Zypper::instance().config().root_dir, "/etc/products.d" ) );
       try
       {
-	XmlFilter::fwd( InputStream( proddir+p.referenceFilename() ), *fwd, std::move(tags)  );
+        XmlFilter::fwd( InputStream( proddir+p.referenceFilename() ), *fwd, std::move(tags)  );
       }
       catch ( const Exception & exp )
       {
-	ZYPP_CAUGHT( exp );	// parse error
+        ZYPP_CAUGHT( exp );	// parse error
       }
     }
   }
@@ -739,7 +749,7 @@ std::string asXML( const Pattern & p, bool is_installed )
     {
       const std::string & text( p.description() );
       if ( ! text.empty() )
-	*xmlout::Node( *parent, "description" ) << xml::escape( text );
+        *xmlout::Node( *parent, "description" ) << xml::escape( text );
     }
   }
   return str.str();
@@ -807,11 +817,11 @@ bool iType( const ui::Selectable::constPtr & sel_r )
 
 const char * computeStatusIndicator( const PoolItem & pi_r, ui::Selectable::constPtr sel_r, bool * iType_r )
 {
-  static const char * _[] = { " ",  " R", " l" };	// not installed / not relevant
-  static const char * i[] = { "i",  "iR", "il" };	// installed     / satisfied
-  static const char * I[] = { "i+", "iR", "il" };	// user installed
-  static const char * v[] = { "v",  "vR", "vl" };	// different version installed
-  static const char * b[] = { "!",  "!R", "!l" };	//               / broken
+  static const char * _[] = { " ",  " l", " P", " R" };	// not installed / not relevant
+  static const char * i[] = { "i",  "il", "iP", "iR" };	// installed     / satisfied
+  static const char * I[] = { "i+", "il", "iP", "iR" };	// user installed
+  static const char * v[] = { "v",  "vl", "vP", "vR" };	// different version installed
+  static const char * b[] = { "!",  "!l", "!P", "!R" };	//               / broken
 
   const char ** stem = _;
   const ResStatus & status { pi_r.status() };
@@ -834,25 +844,29 @@ const char * computeStatusIndicator( const PoolItem & pi_r, ui::Selectable::cons
     if ( sel_r-> hasInstalledObj() )
     {
       if ( sel_r->identicalInstalled( pi_r ) )
-	stem = pi_r.identIsAutoInstalled() ? i : I;
+        stem = pi_r.identIsAutoInstalled() ? i : I;
       else
-	stem = v;
+        stem = v;
     }
     // else _
   }
   // and now the details
   if ( iType_r ) *iType_r = ( *(stem[0]) == 'i' );
-  return stem[pi_r.isRetracted() ? 1 : status.isLocked() ? 2 : 0];
+  if ( pi_r.isBlacklisted() )
+    return stem[pi_r.isPtf() ? 2 : 3];
+  if ( status.isLocked() )
+    return stem[1];
+  return stem[0];
 }
 
 const char * computeStatusIndicator( const ui::Selectable & sel_r, bool tagForeign_r, bool * iType_r )
 {
-  static const char * _[] = { " ",  " R", " l" };	// not installed / not relevant
-  static const char * i[] = { "i",  "iR", "il" };	// installed     / satisfied
-  static const char * I[] = { "i+", "iR", "il" };	// user installed
-  static const char * v[] = { "v",  "vR", "vl" };	// foreign installed
-  static const char * V[] = { "v+", "vR", "vl" };	// foreign user installed
-  static const char * b[] = { "!",  "!R", "!l" };	//               / broken
+  static const char * _[] = { " ",  " l", " P", " R" };	// not installed / not relevant
+  static const char * i[] = { "i",  "il", "iP", "iR" };	// installed     / satisfied
+  static const char * I[] = { "i+", "il", "iP", "iR" };	// user installed
+  static const char * v[] = { "v",  "vl", "vP", "vR" };	// foreign installed
+  static const char * V[] = { "v+", "vl", "vP", "vR" };	// foreign user installed
+  static const char * b[] = { "!",  "!l", "!P", "!R" };	//               / broken
 
   const char ** stem = _;
 
@@ -876,5 +890,9 @@ const char * computeStatusIndicator( const ui::Selectable & sel_r, bool tagForei
   // else _
   // and now the details
   if ( iType_r ) *iType_r = ( *(stem[0]) == 'i' );
-  return stem[sel_r.hasRetractedInstalled() ? 1 : sel_r.locked() ? 2 : 0];
+  if ( sel_r.hasBlacklistedInstalled() )
+    return stem[sel_r.hasPtfInstalled() ? 2 : 3];
+  if ( sel_r.locked() )
+    return stem[1];
+  return stem[0];
 }
