@@ -21,8 +21,9 @@
 #include <zypp/ZYppCommitPolicy.h>
 #include <zypp/base/Logger.h>
 
+#include "Table.h"
+
 class Zypper;
-class Table;
 
 namespace zypp
 {
@@ -63,6 +64,7 @@ bool iType( const ui::Selectable::constPtr & sel_r );
  *   !  - broken/needed Patch
  *
  *  Adds additional suffices for additional information:
+ *   P  - The item is part of a PTF
  *   R  - The item has been retracted
  *   l  - The item is locked
  *   +  - Only for the "i" status, the item is user installed
@@ -84,6 +86,7 @@ inline const char * computeStatusIndicator( const PoolItem & pi_r, bool * iType_
  *      - not installed at all
  *
  *  Adds additional suffices for additional information:
+ *   P  - The item is part of a PTF
  *   R  - The item has been retracted
  *   l  - The item is locked
  *   +  - Only for the "i/v" status, the item is user installed
@@ -190,7 +193,7 @@ Url make_url( const std::string & url_s );
  * Creates Url out of obs://project/platform URI with given base URL and default
  * platform (used in case the platform is not specified in the URI).
  */
-Url make_obs_url( const std::string & obsuri, const Url & base_url, const std::string & default_platform );
+Url make_obs_url( const std::string & obsuri );
 
 /**
  * Returns <code>true</code> if the string \a s contains a substring starting
